/*
 *  AIC3204 Functions
 *
 */

#include "main.h"
#include "data_types.h"
#include "usbstk5515.h"
#include "usbstk5515_i2c.h"
#include <math.h>

#define PI 3.14159265
#define I2C_PORT_AIC3204	(I2C1)
#define I2C_ADDR_AIC3204 	(0X0018)
#define Rcv 0x08
#define Xmit 0x20

// ============================      PROTOTYPES    ===================================
int16_t aic3204_tone_headphone( );
int16_t aic3204_loop_stereo_in1( );
void aic3204_EVM_lp_loopback();
void aic3205_analog_lp_loopback();
void aic3205_analog_pga_loopback();
uint32_t AIC3204_readRegister(uint8_t in_reg_addr, uint8_t *dest_buffer);
uint32_t AIC3204_writeRegister(uint8_t in_reg_addr, uint8_t dest_buffer);
int16_t AIC3204_rset( int16_t regnum, int16_t regval );
void aic3204_init_stereo(void);
void aic3204_init_mono(void);
void aic3204_drc_on(void);


void aic3204_digital_loopback_on()
{
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 29, 0x10 );      // Set ADC loop to DAC
}

void aic3204_digital_loopback_off()
{
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 29, 0x00 );      // Set ADC loop to DAC
}

void aic3204_dac_mute()
{
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 65, 0x81 );      // set LDAC gain to -63.5db
    AIC3204_rset( 66, 0x81 );      // set RDAC gain to -63.5db
}

void aic3204_dac_unmute()
{
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 65, 0x00 );      // set LDAC gain to 0db
    AIC3204_rset( 66, 0x00 );      // set LDAC gain to 0db
}

void aic3204_drc_off()
{


}

void aic3204_drc_on()
{
    AIC3204_rset( 0, 0 );		//	w 30 00 00 #go to page 0
    AIC3204_rset( 65, 24 );		//	w 30 41 18 #make gain of Left DAC=12 dB
    AIC3204_rset( 66, 24 );		//	w 30 42 18 #make gain of right DAC=12 dB
    AIC3204_rset( 68, 0x7F );	//	w 30 44 7F #Enable DRC for both DAC channels, set threshold=24dB, Hysteresis= 3dB
    AIC3204_rset( 69, 0x00 );	//	w 30 45 00 #Make DRC hold=0 ms
    AIC3204_rset( 70, 0xE2 );	//	w 30 46 E2 #Make DRC attack and Decay as required
}
/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  aic3204_init_mono( )                                                           *
 *                                                                          *
 * ------------------------------------------------------------------------ */
void aic3204_init_mono(void)
{
	    /* Configure AIC3204 */

    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 1, 1 );          // Reset codec

    USBSTK5515_waitusec(500);
        
    AIC3204_rset( 0, 1 );          // Point to page 1
    AIC3204_rset( 1, 8 );          // Disable crude AVDD generation from DVDD
    AIC3204_rset( 2, 1 );          // Enable Analog Blocks, use LDO power
    
    /* PLL and Clocks config and Power Up  */
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 27, 0x0d );      // BCLK and WCLK is set as output from AIC3204(Master)
    AIC3204_rset( 28, 0x00 );      // Data ofset = 0
    AIC3204_rset( 4, 3 );          // PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
    AIC3204_rset( 6, 8 );          // PLL setting: J=8
    AIC3204_rset( 7, 0x07 );         // PLL setting: HI_BYTE(D)
    AIC3204_rset( 8, 0x80 );       // PLL setting: LO_BYTE(D)
    AIC3204_rset( 30, 0x88 );      // For 32 bit clocks per frame in Master mode ONLY
                                   // BCLK=DAC_CLK/N =(12000000/8) = 1.714MHz >= 32*fs
    // For 48 KHz sampling 
    AIC3204_rset( 5, 0x91 );       // PLL setting: Power up PLL, P=1 and R=1
    AIC3204_rset( 13, 0x00 );      // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC over sampling
    AIC3204_rset( 14, 0x80 );      // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
    AIC3204_rset( 20, 0x80 );      // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6

    AIC3204_rset( 11, 0x88 );      // Power up NDAC and set NDAC value to 8
    AIC3204_rset( 12, 0x82 );      // Power up MDAC and set MDAC value to 2
    AIC3204_rset( 18, 0x88 );      // Power up NADC and set NADC value to 8
    AIC3204_rset( 19, 0x82 );      // Power up MADC and set MADC value to 2


    AIC3204_rset( 60, 0x19 );      // Power up PRB_P25 for beep generator
//    AIC3204_rset( 61, 0x01 );      // Power up PRB_P21
    
    
    /* DAC ROUTING and Power Up */
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 12, 0x08 );      // LDAC AFIR routed to HPL
    AIC3204_rset( 13, 0x08 );      // RDAC AFIR routed to HPR
//    AIC3204_rset( 14, 0x08 );      // LDAC AFIR routed to LOL
    AIC3204_rset( 14, 0x01 );      // LDAC AFIR routed to LOL
    //    AIC3204_rset( 15, 0x08 );      // RDAC AFIR routed to LOR
    AIC3204_rset( 15, 0x02 );      // MAR routed to LOR
    AIC3204_rset( 25, 0x00 );		//MAR volume (attenuation)
    AIC3204_rset(  0, 0x00 );      // Select page 0
    AIC3204_rset( 64, 0x00 );      // Left vol!=right vol
    AIC3204_rset( 65, 0 );      // Left DAC gain to 20dB VOL;
    AIC3204_rset( 66, 0 );      // Right DAC gain to 0dB VOL;
    AIC3204_rset( 63, 0xd4 );      // Power up left,right data paths and set channel
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 20, 0x69 );		//Soft Step, De-pop, 6 time constants, 6k ohm.      
    AIC3204_rset( 16, 15 );      	// Unmute HPL set gain
    AIC3204_rset( 17, 15 );      	// Unmute HPR set gain
    AIC3204_rset( 18, 0 );      	// Unmute LOL set gain
    AIC3204_rset( 19, 10 );      	// Unmute LOR set gain

    AIC3204_rset( 10, 0x33 );		// HP powered from LDOIN, CM voltage = 1.65V  
    AIC3204_rset(  9, 0x3D );       // Power up HPL, HPR, LOL, LOR, MAR
    
    USBSTK5515_waitusec(500);
    
    /* ADC ROUTING and Power Up */
    AIC3204_rset( 0, 1 );          	// Select page 1
    
    AIC3204_rset( 51, 0x40 );    	// Mic Bias ON

    AIC3204_rset( 52, 0x40 );    	// Mic Input Jack (IN1L)
		                           	// IN1_L to LMicPGA_P through 10 kohm
    AIC3204_rset( 54, 0x40 );       // CM_1L (common mode) to LMicPGA_M through 10 kohm
    		                           	
    AIC3204_rset( 55, 0x30 );    	// Line Input Jack (IN2R)
    								// IN2_R to RADC_P through 40 kohmm
    AIC3204_rset( 57, 0x03 );    	// CM_2R (common mode) to RADC_M through 40 kohm
    
    AIC3204_rset( 59, 30 );       	// MIC_PGA_L gain in .5db steps (Mic)
    AIC3204_rset( 60, 15 );       	// MIC_PGA_R gain in .5db steps (Line)
    
    AIC3204_rset( 0, 0 );  
    AIC3204_rset( 81, 0xc0 );      	// Power up Left and Right ADC
    AIC3204_rset( 83, 15 );      	// Set Left ADC volume (.5db per step)
    AIC3204_rset( 84, 10 );      	// Set Right ADC volume (.5db per step)
    AIC3204_rset( 82, 0x00 );     	// Unmute Left and Right ADC
    
    USBSTK5515_waitusec(500000);

}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  aic3204_init_stereo( )                                                           *
 *                                                                          *
 * ------------------------------------------------------------------------ */
void aic3204_init_stereo(void)
{
	    /* Configure AIC3204 */

    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 1, 1 );          // Reset codec

    USBSTK5515_waitusec(1000);
        
    AIC3204_rset( 0, 1 );          // Point to page 1
    AIC3204_rset( 1, 8 );          // Disable crude AVDD generation from DVDD
    AIC3204_rset( 2, 1 );          // Enable Analog Blocks, use LDO power
    
    /* PLL and Clocks config and Power Up  */
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 27, 0x0d );      // BCLK and WCLK is set as output from AIC3204(Master)
    AIC3204_rset( 28, 0x00 );      // Data ofset = 0
    AIC3204_rset( 4, 3 );          // PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
    AIC3204_rset( 6, 8 );          // PLL setting: J=8
    AIC3204_rset( 7, 15 );         // PLL setting: HI_BYTE(D)
    AIC3204_rset( 8, 0xdc );       // PLL setting: LO_BYTE(D)
    AIC3204_rset( 30, 0x88 );      // For 32 bit clocks per frame in Master mode ONLY
                                   // BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
    // For 48 KHz sampling 
    AIC3204_rset( 5, 0x91 );       // PLL setting: Power up PLL, P=1 and R=1
    AIC3204_rset( 13, 0x00 );         // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
    AIC3204_rset( 14, 0x80 );      // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
    AIC3204_rset( 20, 0x80 );      // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
    AIC3204_rset( 11, 0x88 );      // Power up NDAC and set NDAC value to 8
    AIC3204_rset( 12, 0x82 );      // Power up MDAC and set MDAC value to 2
    AIC3204_rset( 18, 0x88 );      // Power up NADC and set NADC value to 8
    AIC3204_rset( 19, 0x82 );      // Power up MADC and set MADC value to 2
    AIC3204_rset( 60, 0x19 );      // Power up PRB_P25 for beep generator
    
    /* DAC ROUTING and Power Up */
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 12, 0x08 );      // LDAC AFIR routed to HPL
    AIC3204_rset( 13, 0x08 );      // RDAC AFIR routed to HPR
    AIC3204_rset(  0, 0x00 );      // Select page 0
    AIC3204_rset( 64, 0x02 );      // Left vol=right vol
    AIC3204_rset( 65, 0x00 );      // Left DAC gain to 0dB VOL; Right tracks Left
    AIC3204_rset( 63, 0xd4 );      // Power up left,right data paths and set channel
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 16, 15 );      	// Unmute HPL set gain
    AIC3204_rset( 17, 15 );      	// Unmute HPR set gain
    AIC3204_rset( 10, 0x33 );		// HP powered from LDOIN, CM voltage = 1.65V  
    AIC3204_rset( 20, 0x25 );		//De-pop       
    AIC3204_rset(  9, 0x30 );      // Power up HPL,HPR
    AIC3204_rset(  0, 0x00 );      // Select page 0
    
    USBSTK5515_waitusec(3000);
    
    /* ADC ROUTING and Power Up */
    AIC3204_rset( 0, 1 );          	// Select page 1
    AIC3204_rset( 52, 0x30 );    	// Line Input Jack (IN2)
		                           	// IN2_L to LADC_P through 40 kohm
    AIC3204_rset( 55, 0x30 );    	// IN2_R to RADC_P through 40 kohmm
    AIC3204_rset( 54, 0xc0 );       // CM_1 (common mode) to LADC_M through 40 kohm
    AIC3204_rset( 57, 0xc0 );    	// CM_1 (common mode) to RADC_M through 40 kohm
    AIC3204_rset( 59, 20 );       	// MIC_PGA_L gain in db
    AIC3204_rset( 60, 20 );       	// MIC_PGA_R gain in db
    
    AIC3204_rset( 0, 0 );  
    AIC3204_rset( 81, 0xc0 );      // Powerup Left and Right ADC
    AIC3204_rset( 82, 0x00 );      // Unmute Left and Right ADC
    
    USBSTK5515_waitusec(500000);

}

void aic3204_beep_2k_25ms()
{
    AIC3204_rset( 0, 0 );
    AIC3204_rset( 72, 0x80 );		//L&R volume equal
    AIC3204_rset( 73, 0x00 ); 		//Duration msb
    AIC3204_rset( 74, 0x04 );		//Duration
    AIC3204_rset( 75, 0xB0 );    	//Duration lsb
    AIC3204_rset( 76, 0x21 );
    AIC3204_rset( 77, 0x20 );
    AIC3204_rset( 78, 0x7B );
    AIC3204_rset( 79, 0xA3 );
    AIC3204_rset( 71, 0xA3 );		//turn on beep, vol = -30db
}


void aic3204_beep_1k_50ms()
{
    AIC3204_rset( 0, 0 );
    AIC3204_rset( 72, 0x80 );		//L&R volume equal
    AIC3204_rset( 73, 0x00 ); 		//Duration msb
    AIC3204_rset( 74, 0x09 );		//Duration
    AIC3204_rset( 75, 0x60 );    	//Duration lsb
    AIC3204_rset( 76, 0x10 );
    AIC3204_rset( 77, 0xB5 );
    AIC3204_rset( 78, 0x7E );
    AIC3204_rset( 79, 0xE7 );
    AIC3204_rset( 71, 0xA3 );		//turn on beep, vol = -30db
}

void aic3204_beep_800_50ms()
{
    AIC3204_rset( 0, 0 );
    AIC3204_rset( 72, 0x80 );		//L&R volume equal
    AIC3204_rset( 73, 0x00 ); 		//Duration msb
    AIC3204_rset( 74, 0x09 );		//Duration
    AIC3204_rset( 75, 0x60 );    	//Duration lsb
    AIC3204_rset( 76, 0x08 );
    AIC3204_rset( 77, 0x5f );
    AIC3204_rset( 78, 0x7f );
    AIC3204_rset( 79, 0xb9 );
    AIC3204_rset( 71, 0xA3 );		//turn on beep, vol = -30db
}
void aic3204_beep_500_50ms()
{
    AIC3204_rset( 0, 0 );
    AIC3204_rset( 72, 0x80 );		//L&R volume equal
    AIC3204_rset( 73, 0x00 ); 		//Duration msb
    AIC3204_rset( 74, 0x09 );		//Duration
    AIC3204_rset( 75, 0x60 );    	//Duration lsb
    AIC3204_rset( 76, 0x0D );
    AIC3204_rset( 77, 0x61 );
    AIC3204_rset( 78, 0x7f );
    AIC3204_rset( 79, 0x4c );
    AIC3204_rset( 71, 0xA3 );		//turn on beep, vol = -30db
}

//
//int do_sin ()
//{
//  double param, result;
//  param = 30.0;
//  result = sin (param*PI/180);
//  printf ("The sine of %lf degrees is %lf.\n", param, result );
//  return 0;
//}

//	Beep Generator
//	freq = Sin(x) = sin(2*pi*Fin/Fs), where Fin = desired beep frequency, Fs = sample rate
//		sin(2*3.1416*1000/48000)*2^15 =
//	duration_count = number of sample periods (ie 48000S/sec * .250sec = 12000 samples)
//	duration in mSec
void aic3204_beep(uint16_t freq, uint16_t duration, uint16_t attenuation)
{
	uint8_t reg71, reg73, reg74, reg75, reg76, reg77, reg78, reg79;
	uint16_t duration_count, frequency_count_sin, frequency_count_cos;
//	uint32_t rtn;
	double temp, temp2;
	
	duration_count = ((duration * 48000)/1000);
	reg73 = 0;
	reg74 = (duration_count & 0xFF00) >> 8;
	reg75 = (uint8_t)duration_count;
	reg71 = 0x80 | attenuation;
	temp = (2 * PI * freq)/48000;
	temp2=sin(temp);
	frequency_count_sin = temp2* 32768;
	reg76 = (frequency_count_sin & 0xFF00) >> 8;
	reg77 = (uint8_t)frequency_count_sin;
	temp = (2 * PI * freq)/48000;
	temp2 = cos(temp);
	frequency_count_cos = temp2* 32768;
	reg78 = (frequency_count_cos & 0xFF00) >> 8;
	reg79 = (uint8_t)frequency_count_cos;
	
	
    AIC3204_rset( 0, 0 ); 
    AIC3204_rset( 72, 0x80 );		//L&R volume equal
    AIC3204_rset( 73, reg73 ); 		//Duration msb
    AIC3204_rset( 74, reg74 );		//Duration
    AIC3204_rset( 75, reg75 );    	//Duration lsb
// Sine = dec2hex(round(sin(2 x pi x Fin/Fs) x 2^15))    
    AIC3204_rset( 76, reg76 );     	
    AIC3204_rset( 77, reg77 );
    AIC3204_rset( 78, reg78 );     	
    AIC3204_rset( 79, reg79 );

    AIC3204_rset( 71, reg71 );		//turn on beep, vol = -30db     
	USBSTK5515_waitusec(100);
    AIC3204_readRegister(71, &reg71);	//wait for tone to finish
    while (reg71 & 0x80)
    {
        AIC3204_readRegister(71, &reg71);	//wait for tone to finish
    }		
    
//    USBSTK5515_waitusec(100000);

}	


/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  aic3204_analog_lp_loopback( )  
 * 
 * 	Analog Low Power Loopback
 * 
 *  IN1L & IN1R are sent to HPL & HPR bypassing all ADC/DACs                *
 *  The aic3204 must be initilized before calling this function
 *                                                                          *
 * ------------------------------------------------------------------------ */
 void aic3204_analog_lp_loopback(void)
 {
 
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 1, 1 );          // Reset codec
    
    USBSTK5515_waitusec(1000);
        
    AIC3204_rset( 0, 1 );          // Point to page 1
    AIC3204_rset( 1, 8 );          // Disable crude AVDD generation from DVDD
    AIC3204_rset( 2, 1 );          // Enable Analog Blocks, use LDO power

    
    /* PLL and Clocks config and Power Up  */
    AIC3204_rset( 0, 0 );          // Select page 0    
    AIC3204_rset( 27, 0x0d );      // BCLK and WCLK is set as output from AIC3204(Master)
    AIC3204_rset( 28, 0x00 );      // Data ofset = 0
    AIC3204_rset( 4, 3 );          // PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
    AIC3204_rset( 6, 8 );          // PLL setting: J=8
    AIC3204_rset( 7, 15 );         // PLL setting: HI_BYTE(D)
    AIC3204_rset( 8, 0xdc );       // PLL setting: LO_BYTE(D)
    AIC3204_rset( 30, 0x88 );      // For 32 bit clocks per frame in Master mode ONLY
                                   // BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
    // For 48 KHz sampling 
    AIC3204_rset( 5, 0x91 );       // PLL setting: Power up PLL, P=1 and R=1
    AIC3204_rset( 13, 0 );         // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
    AIC3204_rset( 14, 0x80 );      // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
    AIC3204_rset( 20, 0x80 );      // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
    AIC3204_rset( 11, 0x88 );      // Power up NDAC and set NDAC value to 8
    AIC3204_rset( 12, 0x82 );      // Power up MDAC and set MDAC value to 2
    AIC3204_rset( 18, 0x88 );      // Power up NADC and set NADC value to 8
    AIC3204_rset( 19, 0x82 );      // Power up MADC and set MADC value to 2
    
    /* DAC ROUTING and Power Up */
//    AIC3204_rset(  0, 0x01 );      // Select page 1
//    AIC3204_rset( 12, 0x08 );      // LDAC AFIR routed to HPL
//    AIC3204_rset( 13, 0x08 );      // RDAC AFIR routed to HPR
//    AIC3204_rset(  0, 0x00 );      // Select page 0
//    AIC3204_rset( 64, 0x02 );      // Left vol=right vol
//    AIC3204_rset( 65, 0x00 );      // Left DAC gain to 0dB VOL; Right tracks Left
//    AIC3204_rset( 63, 0xd4 );      // Power up left,right data paths and set channel
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 16, 0x00 );      // Unmute HPL, set gain
    AIC3204_rset( 17, 0x00 );      // Unmute HPR, set gain
    AIC3204_rset(  9, 0x30 );      // Power up HPL,HPR
     	 	
    USBSTK5515_waitusec(500);
    
    /* ADC ROUTING and Power Up */  	
    AIC3204_rset( 0, 1 );          	// Select page 1   
    AIC3204_rset( 12, 0x04 );    	// IN1L is routed to HPL 	
    AIC3204_rset( 22, 0 );			// set IN1L HPL atten in db
    AIC3204_rset( 13, 0x04 );    	// IN1R is routed to HPR 
    AIC3204_rset( 23, 0 );			// set IN1R HPR atten in db
    AIC3204_rset( 0, 0 );  
 }
 
/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  aic3204_analog_pga_loopback( )  
 * 
 * 	Analog Loopback via PGA
 * 
 * 	Input from IN2 sent to HP out via PGA                         			*
 * 	The aic3204 must be initilized before calling this function
 *                                                                          *
 * ------------------------------------------------------------------------ */
 void aic3204_analog_pga_loopback(void)
 {
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 1, 1 );          // Reset codec
    
    USBSTK5515_waitusec(1000);
    
    AIC3204_rset( 0, 1 );          // Point to page 1
    AIC3204_rset( 1, 8 );          // Disable crude AVDD generation from DVDD
    AIC3204_rset( 2, 1 );          // Enable Analog Blocks, use LDO power

    /* PLL and Clocks config and Power Up  */
    AIC3204_rset( 0, 0 );          // Select page 0
    AIC3204_rset( 27, 0x0d );      // BCLK and WCLK is set as output from AIC3204(Master)
    AIC3204_rset( 28, 0x00 );      // Data ofset = 0
    AIC3204_rset( 4, 3 );          // PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
    AIC3204_rset( 6, 8 );          // PLL setting: J=8
    AIC3204_rset( 7, 15 );         // PLL setting: HI_BYTE(D)
    AIC3204_rset( 8, 0xdc );       // PLL setting: LO_BYTE(D)
    AIC3204_rset( 30, 0x88 );      // For 32 bit clocks per frame in Master mode ONLY
                                   // BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
    // For 48 KHz sampling 
    AIC3204_rset( 5, 0x91 );       // PLL setting: Power up PLL, P=1 and R=1
    AIC3204_rset( 13, 0 );         // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
    AIC3204_rset( 14, 0x80 );      // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
    AIC3204_rset( 20, 0x80 );      // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
    AIC3204_rset( 11, 0x88 );      // Power up NDAC and set NDAC value to 8
    AIC3204_rset( 12, 0x82 );      // Power up MDAC and set MDAC value to 2
    AIC3204_rset( 18, 0x88 );      // Power up NADC and set NADC value to 8
    AIC3204_rset( 19, 0x82 );      // Power up MADC and set MADC value to 2
    
    /* DAC ROUTING and Power Up */
    AIC3204_rset(  0, 0x01 );      	// Select page 1
    AIC3204_rset( 12, 0x08 );      // LDAC AFIR routed to HPL
    AIC3204_rset( 13, 0x08 );      // RDAC AFIR routed to HPR
    AIC3204_rset(  0, 0x00 );      	// Select page 0
    AIC3204_rset( 64, 0x02 );      // Left vol=right vol
    AIC3204_rset( 65, 0x00 );      // Left DAC gain to 0dB VOL; Right tracks Left
    AIC3204_rset( 63, 0xd4 );      	// Power up left,right data paths and set channel
    AIC3204_rset(  0, 0x01 );      	// Select page 1
    AIC3204_rset( 16, 20 );      	// Unmute HPL , 6dB gain
    AIC3204_rset( 17, 20 );      	// Unmute HPR , 6dB gain
    AIC3204_rset( 18, 6 );      	// Unmute LOL , 6dB gain
    AIC3204_rset( 19, 6 );      	// Unmute LOR , 6dB gain
    AIC3204_rset( 10, 0x33 );       // HP powered from LDOIN, CM voltage = 1.65V    
    AIC3204_rset(  9, 0x3f );      	// Power up HPL,HPR,LOL,LOR
     	
    USBSTK5515_waitusec(1000);
    
    /* ADC ROUTING and Power Up */
    AIC3204_rset( 0, 1 );          	// Select page 1
    AIC3204_rset( 52, 0x30 );    	// Line Input Jack (IN2)
		                           	// IN2_L to LADC_P through 40 kohm
    AIC3204_rset( 55, 0x30 );    	// IN2_R to RADC_P through 40 kohmm
    AIC3204_rset( 54, 0xc0 );       // CM_1 (common mode) to LADC_M through 40 kohm
    AIC3204_rset( 57, 0xc0 );    	// CM_1 (common mode) to RADC_M through 40 kohm
    AIC3204_rset( 59, 0x20 );       // MIC_PGA_L gain=6db
    AIC3204_rset( 60, 0x20 );       // MIC_PGA_R gain=6db
    AIC3204_rset( 12, 0x02 );    	// MAL is routed to HPL
    AIC3204_rset( 13, 0x02 );    	// MAR is routed to HPR    
    AIC3204_rset( 14, 0x02 );    	// MAL is routed to LOL
    AIC3204_rset( 15, 0x02 );    	// MAR is routed to LOR   
//	AIC3204_rset( 9, 0x33 );    	// Power on HP & Mixer Amps (L&R)
    AIC3204_rset( 0, 0 );  
 }
 

void aic3204_EVM_lp_loopback()
{
// 
// ###############################################
//# Direct Analog Bypass
//# ---------------------------------------------
//# This script routes IN1_L/R inputs to HPL/R
//# outputs. Connect a portable media player
//# to J1 (IN1_L/R) and headphones to J9.
//#
//# Ensure the input signal does not exceed the
//# maximum rated input voltage.
//###############################################
//
//
//
//###############################################
//# Software Reset
//###############################################
//#
//# Select Page 0
//w 30 00 00
    AIC3204_rset( 0, 0 ); 
//# Initialize the device through software reset
//w 30 01 01
    AIC3204_rset( 1, 1 ); 
//#
//###############################################
//
//
//
//###############################################
//# Initialize Codec
//###############################################
//#
//# Select Page 1
//w 30 00 01
    AIC3204_rset( 0x00, 0x01 ); 
//#
//# Disable weak AVDD in presence of external
//# AVDD supply
//w 30 01 08
    AIC3204_rset( 0x01, 0x08 ); 
//#
//# Enable Master Analog Power Control
//w 30 02 00
    AIC3204_rset( 0x02, 0x01 ); 		//enable AVDD LDO
//#
//# Set the input powerup time to 3.1ms (for ADC)
//# w 30 47 32
    AIC3204_rset( 0x047, 0x032 ); 
//#
//# Set the REF charging time to 40ms
//w 30 7b 01
    AIC3204_rset( 0x07b, 0x01 ); 
//#
//###############################################
//
//
//
//###############################################
//# Playback Setup
//###############################################
//#
//# Select Page 1
//w 30 00 01
    AIC3204_rset( 0x00, 0x01 ); 
//#
//# De-pop
//w 30 14 25
    AIC3204_rset( 0x14, 0x25 ); 
//#
//# Direct Bypass Gain = 0dB
//w 30 16 00 00
    AIC3204_rset( 0x16, 0x00 );
    AIC3204_rset( 0x17, 0x00 );
//#
//# Route IN_1L/R to HPL/R
//w 30 0C 04 04
    AIC3204_rset( 0x0c, 0x04 ); 
    AIC3204_rset( 0x0d, 0x04 );
//#
//# Power up HPL/HPR drivers
//w 30 09 30
    AIC3204_rset( 0x09, 0x30 );
//#
//# Unmute HPL/HPR driver, -5dB Gain
//w 30 10 3B 3B
    AIC3204_rset( 0x10, 0x3b );
    AIC3204_rset( 0x11, 0x3b );    
//#
//###############################################
// 
// 
 }
 

//
///* ------------------------------------------------------------------------ *
// *                                                                          *
// *  aic3204_test( )                                                           *
// *                                                                          *
// * ------------------------------------------------------------------------ */
//int16_t aic3204_test( )
//{
////	SYS_EXBUSSEL = 0x6100;         // Enable I2C bus
////	USBSTK5515_I2C_init( );        // Initialize I2C
//   
//    /* Codec tests */
////    printf( " -> 1 KHz Tone on Headphone (J4).\n" );
////    if ( aic3204_tone_headphone( ) )
////        return 1;
//       
////    USBSTK5515_wait( 100 );  // Wait    
//    printf( "<-> Audio Loopback from Stereo IN 1 (J3) --> to HP (J4)\n" );
//    if ( aic3204_loop_stereo_in1( ) )
//        return 1;
//
//    return 0;
//}

/*
 *  AIC3204 Tone
 *
 */
 



//
///* ------------------------------------------------------------------------ *
// *                                                                          *
// *  AIC3204 Loop                                                            *
// *      Output input from STEREO IN 1 through the HEADPHONE jack            *
// *                                                                          *
// * ------------------------------------------------------------------------ */
//int16_t aic3204_loop_stereo_in1( )
//{
///* Pre-generated sine wave data, 16-bit signed samples */
//int16_t j, i = 0;
//int16_t sample, data1, data2, data3, data4, in_pointer;
//  
//    /* Configure AIC3204 */
//
//    AIC3204_rset( 0, 0 );          // Select page 0
//    AIC3204_rset( 1, 1 );          // Reset codec
//    AIC3204_rset( 0, 1 );          // Point to page 1
//    AIC3204_rset( 1, 8 );          // Disable crude AVDD generation from DVDD
//    AIC3204_rset( 2, 1 );          // Enable Analog Blocks, use LDO power
//    AIC3204_rset( 0, 0 );          // Select page 0
//    /* PLL and Clocks config and Power Up  */
//    AIC3204_rset( 27, 0x0d );      // BCLK and WCLK is set as o/p to AIC3204(Master)
//    AIC3204_rset( 28, 0x00 );      // Data ofset = 0
//    AIC3204_rset( 4, 3 );          // PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
//    AIC3204_rset( 6, 8 );          // PLL setting: J=8
//    AIC3204_rset( 7, 15 );         // PLL setting: HI_BYTE(D)
//    AIC3204_rset( 8, 0xdc );       // PLL setting: LO_BYTE(D)
//    AIC3204_rset( 30, 0x88 );      // For 32 bit clocks per frame in Master mode ONLY
//                                   // BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
//    AIC3204_rset( 5, 0x91 );       // PLL setting: Power up PLL, P=1 and R=1
//    AIC3204_rset( 13, 0 );         // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
//    AIC3204_rset( 14, 0x80 );      // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
//    AIC3204_rset( 20, 0x80 );      // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
//    AIC3204_rset( 11, 0x88 );      // Power up NDAC and set NDAC value to 8
//    AIC3204_rset( 12, 0x82 );      // Power up MDAC and set MDAC value to 2
//    AIC3204_rset( 18, 0x88 );      // Power up NADC and set NADC value to 8
//    AIC3204_rset( 19, 0x82 );      // Power up MADC and set MADC value to 2
//    /* DAC ROUTING and Power Up */
//    AIC3204_rset(  0, 0x01 );      // Select page 1
//    AIC3204_rset( 12, 0x08 );      // LDAC AFIR routed to HPL
//    AIC3204_rset( 13, 0x08 );      // RDAC AFIR routed to HPR
//    AIC3204_rset(  0, 0x00 );      // Select page 0
//    AIC3204_rset( 64, 0x02 );      // Left vol=right vol
//    AIC3204_rset( 65, 0x00 );      // Left DAC gain to 0dB VOL; Right tracks Left
//    AIC3204_rset( 63, 0xd4 );      // Power up left,right data paths and set channel
//    AIC3204_rset(  0, 0x01 );      // Select page 1
//    AIC3204_rset( 16, 0x06 );      // Unmute HPL , 6dB gain
//    AIC3204_rset( 17, 0x06 );      // Unmute HPR , 6dB gain
//    AIC3204_rset(  9, 0x30 );      // Power up HPL,HPR
//    AIC3204_rset(  0, 0x00 );      // Select page 0
////    USBSTK5515_wait( 500 );        // Wait
//    
//    /* ADC ROUTING and Power Up */
//    AIC3204_rset( 0, 1 );          // Select page 1
//    AIC3204_rset( 0x34, 0x30 );    // STEREO 1 Jack
//		                           // IN2_L to LADC_P through 40 kohm
//    AIC3204_rset( 0x37, 0x30 );    // IN2_R to RADC_P through 40 kohmm
//    AIC3204_rset( 0x36, 3 );       // CM_1 (common mode) to LADC_M through 40 kohm
//    AIC3204_rset( 0x39, 0xc0 );    // CM_1 (common mode) to RADC_M through 40 kohm
//    AIC3204_rset( 0x3b, 0 );       // MIC_PGA_L unmute
//    AIC3204_rset( 0x3c, 0 );       // MIC_PGA_R unmute
//    AIC3204_rset( 0, 0 );          // Select page 0
//    AIC3204_rset( 0x51, 0xc0 );    // Powerup Left and Right ADC
//    AIC3204_rset( 0x52, 0 );       // Unmute Left and Right ADC
//    
//    AIC3204_rset( 0, 0 );    
////    USBSTK5515_wait( 200 );  // Wait
//
////    /* I2S settings */
////    I2S0_SRGR = 0x0;
////    I2S0_CR = 0x8010;    // 16-bit word, slave, enable I2C
////    I2S0_ICMR = 0x3f;    // Enable interrupts
//    
//    /* Loopback stereo input to output */
////    for ( i = 0 ; i < 5 ; i++ )
//
//
//
//  /* Play Tone */
//    for ( i = 0 ; i < 5 ; i++ )
//    {
//        for ( j = 0 ; j < 1000 ; j++ )
//        {
//            for ( sample = 0 ; sample < 48 ; sample++ )
//            {
//            	/* Read Digital audio input */
//                data3 = I2S0_W0_MSW_R;  // 16 bit left channel received audio data
//      	        data1 = I2S0_W0_LSW_R;
//      	        data4 = I2S0_W1_MSW_R;  // 16 bit right channel received audio data
//      	        data2 = I2S0_W1_LSW_R;
//            	while((Rcv & I2S0_IR) == 0);  // Wait for interrupt pending flag
//				/* Write Digital audio input */
//				I2S0_W0_MSW_W = data3;  // 16 bit left channel transmit audio data
//      	        I2S0_W0_LSW_W = 0;
//      	        I2S0_W1_MSW_W = data4;  // 16 bit right channel transmit audio data
//      	        I2S0_W1_LSW_W = 0;
//      	        while((Xmit & I2S0_IR) == 0);  // Wait for interrupt pending flag
//            }
//        }
//
//
//
////
////
////
////	while(1)
////    {       
////            for ( sample = 0 ; sample < XMIT_BUFF_SIZE ; sample++ )
////            {
////            	/* Read Digital audio input */
////                in[sample] = I2S0_W0_MSW_R;  // 16 bit left channel received audio data              
//// //     	        data1 = I2S0_W0_LSW_R;
////      	        in[sample+1] = I2S0_W1_MSW_R;  // 16 bit right channel received audio data
//// //     	        data2 = I2S0_W1_LSW_R;
////      	        sample++;
////      	        while((Rcv & I2S0_IR) == 0);  // Wait for interrupt pending flag
////            }
//// //           LoopCodec();
////            for (i=0;i<XMIT_BUFF_SIZE;i++) 
////            {
////            	out[i]=in[i];
////            }
////            for (sample=0; sample < XMIT_BUFF_SIZE; sample++)
////            {
////				/* Write Digital audio input */
////				I2S0_W0_MSW_W = out[sample];  // 16 bit left channel transmit audio data
////      	        I2S0_W0_LSW_W = 0;
////      	        I2S0_W1_MSW_W = out[sample+1];  // 16 bit right channel transmit audio data
////      	        I2S0_W1_LSW_W = 0;
////      	        while((Xmit & I2S0_IR) == 0);
////      	        sample++;  // Wait for interrupt pending flag
////            }
////      }
//      
//    /* Disble I2S */
//    I2S0_CR = 0x00;
//   
//    return 0;
//}
//
//
///*
// *  Copyright 2010 by Spectrum Digital Incorporated.
// *  All rights reserved. Property of Spectrum Digital Incorporated.
// */
//
///*
// *  AIC3204 Tone
// *
// */
//
////#include "stdio.h"
////#include "usbstk5515.h"
//
//#define Xmit 0x20
/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  AIC3204 Tone                                                            *
 *      Output a 1 kHz tone through the STEREO OUT jack                      *
 *                                                                          *
 * ------------------------------------------------------------------------ */
int16_t aic3204_tone_lineout( )
{
    /* Pre-generated sine wave data, 16-bit signed samples */
    uint16_t sinetable[48] = {
        0x0000, 0x10b4, 0x2120, 0x30fb, 0x3fff, 0x4dea, 0x5a81, 0x658b,
        0x6ed8, 0x763f, 0x7ba1, 0x7ee5, 0x7ffd, 0x7ee5, 0x7ba1, 0x76ef,
        0x6ed8, 0x658b, 0x5a81, 0x4dea, 0x3fff, 0x30fb, 0x2120, 0x10b4,
        0x0000, 0xef4c, 0xdee0, 0xcf06, 0xc002, 0xb216, 0xa57f, 0x9a75,
        0x9128, 0x89c1, 0x845f, 0x811b, 0x8002, 0x811b, 0x845f, 0x89c1,
        0x9128, 0x9a76, 0xa57f, 0xb216, 0xc002, 0xcf06, 0xdee0, 0xef4c
    };
    int16_t j, i = 0;
    int16_t sample;
   
     /* Configure AIC3204 */
    AIC3204_rset(  0, 0x00 );      // Select page 0
    AIC3204_rset(  1, 0x01 );      // Reset codec
    AIC3204_rset(  0, 0x01 );      // Point to page 1
    AIC3204_rset(  1, 0x08 );      // Disable crude AVDD generation from DVDD
    AIC3204_rset(  2, 0x01 );      // Enable Analog Blocks
    AIC3204_rset(  0, 0x00 );      // Select page 0
    // PLL and Clocks config and Power Up  
    AIC3204_rset( 27, 0x0D );      // BCLK and WCLK is set as i/p to AIC3204(Slave)
    AIC3204_rset( 28, 0x00 );      // Data ofset = 0
    AIC3204_rset(  4, 0x03 );      // PLL setting: PLLCLK <- BCLK and CODEC_CLKIN <-PLL CLK
    AIC3204_rset(  6, 0x08 );      // PLL setting: J=32
    AIC3204_rset(  7, 15 );        // PLL setting: HI_BYTE(D = 0)
    AIC3204_rset(  8, 0xdc );        // PLL setting: LO_BYTE(D) = 0
    AIC3204_rset( 30, 0x88 );      // For 32 bit clocks per frame in Master mode ONLY
                                   // BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
    // For 48 KHz sampling 
    AIC3204_rset(  5, 0x91 );      // PLL setting: Power up PLL, P=1 and R=2
    AIC3204_rset( 13, 0x00 );      // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
    AIC3204_rset( 14, 0x80 );      // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
    AIC3204_rset( 20, 0x80 );      // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
    AIC3204_rset( 11, 0x88 );      // Power up NDAC and set NDAC value to 8
    AIC3204_rset( 12, 0x82 );      // Power up MDAC and set MDAC value to 2
    AIC3204_rset( 18, 0x88 );      // Power up NADC and set NADC value to 8
    AIC3204_rset( 19, 0x82 );      // Power up MADC and set MADC value to 2
    // DAC ROUTING and Power Up 
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 12, 0x08 );      // LDAC AFIR routed to LOL
    AIC3204_rset( 13, 0x08 );      // RDAC AFIR routed to LOR
    AIC3204_rset(  0, 0x00 );      // Select page 0
    AIC3204_rset( 64, 0x02 );      // Left vol=right vol
    AIC3204_rset( 65, 0x00 );      // Left DAC gain to 0dB VOL; Right tracks Left
    AIC3204_rset( 63, 0xd4 );      // Power up left,right data paths and set channel
    AIC3204_rset(  0, 0x01 );      // Select page 1
    AIC3204_rset( 16, 0x3a );      // Unmute LOL , -6dB gain
    AIC3204_rset( 17, 0x3a );      // Unmute LOR , -6dB gain
    AIC3204_rset(  9, 0x0C );      // Power up LOL,LOR
    AIC3204_rset(  0, 0x00 );      // Select page 0
//    USBSTK5515_wait( 500 );        // Wait
    /* ADC ROUTING and Power Up */
    AIC3204_rset( 0, 1 );          // Select page 1
    AIC3204_rset( 52, 0x30 );      // STEREO 1 Jack
		                           // IN2_L to LADC_P through 40 kohm
    AIC3204_rset( 55, 0x30 );      // IN2_R to RADC_P through 40 kohmm
    AIC3204_rset( 54, 0x03 );      // CM_1 (common mode) to LADC_M through 40 kohm
    AIC3204_rset( 57, 0xc0 );      // CM_1 (common mode) to RADC_M through 40 kohm
    AIC3204_rset( 59, 0x00 );      // MIC_PGA_L unmute
    AIC3204_rset( 60, 0x00 );      // MIC_PGA_R unmute
    AIC3204_rset(  0, 0x00 );      // Select page 0
    AIC3204_rset( 81, 0xc0 );      // Powerup Left and Right ADC
    AIC3204_rset( 82, 0x00 );      // Unmute Left and Right ADC
    
    AIC3204_rset( 0,  0x00 );    
	////    USBSTK5515_wait( 200 );  // Wait
	USBSTK5515_waitusec(200);
    
//    /* I2S settings */
//    I2S0_SRGR = 0x0;
//    I2S0_CR = 0x8010;    // 16-bit word, slave, enable I2C
//    I2S0_ICMR = 0x3f;    // Enable interrupts
    
    /* Play Tone */
    for ( i = 0 ; i < 5 ; i++ )
    {
        for ( j = 0 ; j < 1000 ; j++ )
        {
            for ( sample = 0 ; sample < 48 ; sample++ )
            {
//   				MCASP->XBUF11 = (sinetable[sample]) ; // 16 bit left channel transmit audio data
//   				while(!CHKBIT(MCASP->SRCTL11, XRDY)) {}        // Wait for transmit interrupt to be pending
            }
        }
    }
    /* Disble I2S */
//    I2S0_CR = 0x00;
   
    return 0;
}

//
///*
// *  Copyright 2009 by Spectrum Digital Incorporated.
// *  All rights reserved. Property of Spectrum Digital Incorporated.
// */
//
///*
// *  AIC3204 Tone
// *
// */
////#include "stdio.h"
////#include "usbstk5515.h"
//
//#define XmitL 0x10
//#define XmitR 0x20
///* ------------------------------------------------------------------------ *
// *                                                                          *
// *  AIC3204 Tone                                                            *
// *      Output a 1 kHz tone through the HEADPHONE jack                      *
// *                                                                          *
// * ------------------------------------------------------------------------ */
//int16_t aic3204_tone_headphone( )
//{
//    /* Pre-generated sine wave data, 16-bit signed samples */
//    int16_t sinetable[48] = {
//        0x0000, 0x10b4, 0x2120, 0x30fb, 0x3fff, 0x4dea, 0x5a81, 0x658b,
//        0x6ed8, 0x763f, 0x7ba1, 0x7ee5, 0x7ffd, 0x7ee5, 0x7ba1, 0x76ef,
//        0x6ed8, 0x658b, 0x5a81, 0x4dea, 0x3fff, 0x30fb, 0x2120, 0x10b4,
//        0x0000, 0xef4c, 0xdee0, 0xcf06, 0xc002, 0xb216, 0xa57f, 0x9a75,
//        0x9128, 0x89c1, 0x845f, 0x811b, 0x8002, 0x811b, 0x845f, 0x89c1,
//        0x9128, 0x9a76, 0xa57f, 0xb216, 0xc002, 0xcf06, 0xdee0, 0xef4c
//    };
//    int16_t j, i = 0;
//    int16_t sample;
//
//    /* Configure AIC3204 */
//
//    AIC3204_rset( 0, 0 );      // Select page 1
//    AIC3204_rset( 1, 1 );      // Reset codec
//    AIC3204_rset( 0, 1 );      // Point to page 1
//    AIC3204_rset( 1, 8 );      // Disable crude AVDD generation from DVDD
//    AIC3204_rset( 2, 1 );      // Enable Analog Blocks, use LDO power
//    AIC3204_rset( 0, 0 );
//    /* PLL and Clocks config and Power Up  */
//    AIC3204_rset( 27, 0x0d );  // BCLK and WCLK is set as o/p to AIC3204(Master)
//    AIC3204_rset( 28, 0x00 );  // Data ofset = 0
//    AIC3204_rset( 4, 3 );      // PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
//    AIC3204_rset( 6, 8 );      // PLL setting: J=8
//    AIC3204_rset( 7, 15 );     // PLL setting: HI_BYTE(D)
//    AIC3204_rset( 8, 0xdc );   // PLL setting: LO_BYTE(D)
//    AIC3204_rset( 30, 0x88 );  // For 32 bit clocks per frame in Master mode ONLY
//                               // BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
//    AIC3204_rset( 5, 0x91 );   //?;PLL setting: Power up PLL, P=1 and R=1
//    AIC3204_rset( 13, 0 );     // Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
//    AIC3204_rset( 14, 0x80 );  // Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
//    AIC3204_rset( 20, 0x80 );  // AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
//    AIC3204_rset( 11, 0x88 );  // Power up NDAC and set NDAC value to 8
//    AIC3204_rset( 12, 0x82 );  // Power up MDAC and set MDAC value to 2
//    AIC3204_rset( 18, 0x88 );  // Power up NADC and set NADC value to 8
//    AIC3204_rset( 19, 0x82 );  // Power up MADC and set MADC value to 2
//    /* DAC ROUTING and Power Up */
//    AIC3204_rset( 0, 1 );      // Select page 1
//    AIC3204_rset( 0x0c, 8 );   // LDAC AFIR routed to HPL
//    AIC3204_rset( 0x0d, 8 );   // RDAC AFIR routed to HPR
//    AIC3204_rset( 0, 0 );      // Select page 0
//    AIC3204_rset( 64, 2 );     // Left vol=right vol
//    AIC3204_rset( 65, 0);      // Left DAC gain to 0dB VOL; Right tracks Left
//    AIC3204_rset( 63, 0xd4 );  // Power up left,right data paths and set channel
//    AIC3204_rset( 0, 1 );      // Select page 1
//    AIC3204_rset( 0x10, 0x3a );// Unmute HPL , -6dB gain
//    AIC3204_rset( 0x11, 0x3a );// Unmute HPR , -6dB gain
//    AIC3204_rset( 9, 0x30 );   // Power up HPL,HPR
//    AIC3204_rset( 0, 0 );      // Select page 0
////    USBSTK5515_wait( 100 );    // wait
//    /* ADC ROUTING and Power Up */
//    AIC3204_rset( 0, 1 );      // Select page 1
//    AIC3204_rset( 0x34, 0x30 );// STEREO 1 Jack
//		                       // IN2_L to LADC_P through 40 kohm
//    AIC3204_rset( 0x37, 0x30 );// IN2_R to RADC_P through 40 kohmm
//    AIC3204_rset( 0x36, 3 );   // CM_1 (common mode) to LADC_M through 40 kohm
//    AIC3204_rset( 0x39, 0xc0 );// CM_1 (common mode) to RADC_M through 40 kohm
//    AIC3204_rset( 0x3b, 0 );   // MIC_PGA_L unmute
//    AIC3204_rset( 0x3c, 0 );   // MIC_PGA_R unmute
//    AIC3204_rset( 0, 0 );      // Select page 0
//    AIC3204_rset( 0x51, 0xc0 );// Powerup Left and Right ADC
//    AIC3204_rset( 0x52, 0 );   // Unmute Left and Right ADC
//    
//    AIC3204_rset( 0, 0 );    
//    
////    USBSTK5515_wait( 200 );  // Wait
////    /* I2S settings */
////    I2S0_SRGR = 0x0;
////    I2S0_CR = 0x8010;    // 16-bit word, slave, enable I2C
////    I2S0_ICMR = 0x3f;    // Enable interrupts
//
//    /* Play Tone */
//    for ( i = 0 ; i < 5 ; i++ )
//    {
//        for ( j = 0 ; j < 1000 ; j++ )
//        {
//            for ( sample = 0 ; sample < 48 ; sample++ )
//            {
//                I2S0_W0_MSW_W = (sinetable[sample]) ; // 16 bit left channel transmit audio data
//                I2S0_W1_MSW_W = (sinetable[sample]) ; // 16 bit right channel transmit audio data
//
//                while((XmitR & I2S0_IR) == 0);        // Wait for transmit interrupt to be pending
//            }
//        }
//    }
//    /* Disble I2S */
//    I2S0_CR = 0x00;
//   
//   
//    return 0;
//}


/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _AIC3204_rget( regnum, regval )                                         *
 *                                                                          *
 *      Return value of codec register regnum                               *
 *                                                                          *
 * ------------------------------------------------------------------------ */
//int16_t AIC3204_rget(  Uint16 regnum, Uint16* regval )
//{
//    int16_t retcode = 0;
//    Uint8 cmd[2];
//
//    cmd[0] = regnum & 0x007F;       // 7-bit Register Address
//    cmd[1] = 0;
//
////    retcode |= AIC3204_writeRegister((uint8_t)regnum, (uint8_t)regval );
//    retcode |= AIC3204_readRegister( (Uint8)regnum, (Uint8*)regval );
////
//    *regval = cmd[0];
////    USBSTK5515_wait( 10 );
//    return retcode;
//}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _AIC3204_rset( regnum, regval )                                         *
 *                                                                          *
 *      Set codec register regnum to value regval                           *
 *                                                                          *
 * ------------------------------------------------------------------------ */
int16_t AIC3204_rset( int16_t regnum, int16_t regval )
{

	return AIC3204_writeRegister((uint8_t) regnum, (uint8_t) regval);
}


//-----------------------------------------------------------------------------
// /brief Read data from a register on the AIC3204.
// 
// /param uint8_t in_reg_addr: The address of the register to be read from.
//
// /param uint8_t * dest_buffer: Pointer to buffer to store retrieved data.
//
// /return uint32_t ERR_NO_ERROR on success
//
//-----------------------------------------------------------------------------
uint32_t AIC3204_readRegister(uint8_t in_reg_addr, uint8_t *dest_buffer)
{
   uint32_t rtn;

   // write the register address that we want to read.
//   Int16 USBSTK5515_I2C_write( Uint16 i2c_addr, Uint8* data, Uint16 len );
   rtn = USBSTK5515_I2C_write(AIC3204_I2C_ADDR, &in_reg_addr, 1 );
//   rtn = I2C_write(I2C_PORT_AIC3204, I2C_ADDR_AIC3204, &in_reg_addr, 1, SKIP_STOP_BIT_AFTER_WRITE);
   if (rtn != ERR_NO_ERROR)
      return (rtn);

   // clock out the register data.
//   rtn = I2C_read(I2C_PORT_AIC3204, I2C_ADDR_AIC3204, dest_buffer, 1, SKIP_BUSY_BIT_CHECK);
//   Int16 USBSTK5515_I2C_read( Uint16 i2c_addr, Uint8* data, Uint16 len );
   USBSTK5515_I2C_read( AIC3204_I2C_ADDR, dest_buffer, 1 );
   
   return (rtn);
}

//-----------------------------------------------------------------------------
// /brief Write a register on the AIC3204.
// 
// /param uint8_t in_reg_addr: The address of the register to be written to.
//
// /param uint8_t data: Data to be written to the register
//
// /return uint32_t ERR_NO_ERROR on sucess
//
//-----------------------------------------------------------------------------
uint32_t AIC3204_writeRegister(uint8_t in_reg_addr, uint8_t in_data)
{
   uint32_t rtn;
   uint8_t i2c_data[2];
   
   i2c_data[0] = in_reg_addr;
   i2c_data[1] = in_data;

   // write the register that we want to read.
//   USBSTK5515_I2C_write( Uint16 i2c_addr, Uint8* data, Uint16 len )
   rtn = USBSTK5515_I2C_write( in_reg_addr, i2c_data, 2 );
//   rtn = I2C_write(I2C_PORT_AIC3204, I2C_ADDR_AIC3204, i2c_data, 2, SET_STOP_BIT_AFTER_WRITE);

   return (rtn);
}
